==> csawBook_1.4.1.tar.gz: csawBook/inst/doc/book/index.md <==
--- 
title: "The csaw Book"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
description: "ChIP-seq Analysis with Windows. But it works on Mac and Linux too!"
github-repo: LTLA/csawUsersGuide
---



---
date: "**Authors:** Aaron Lun [aut, cre]<br/>
  **Version:** 1.4.1<br/>
  **Modified:** 2021-08-28<br/>
  **Compiled:** 2022-08-29<br/>
  **Environment:** R version 4.2.1 (2022-06-23), Bioconductor 3.15<br/>
  **License:** GPL-3<br/>
  **Copyright:** Bioconductor, 2020<br/>
  **Source:** https://github.com/LTLA/csawUsersGuide"
url: "https://github.com/LTLA/csawUsersGuide"
---

# Welcome

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

Chromatin immunoprecipitation with sequencing (ChIP-seq) is a widely used technique for identifying the genomic binding sites of a target protein.
Conventional analyses of ChIP-seq data aim to detect absolute binding (i.e., the presence or absence of a binding site) based on peaks in the read coverage.
An alternative analysis strategy is to detect of changes in the binding profile between conditions [@rossinnes2012differential; @pal2013].
These differential binding (DB) analyses involve counting reads into genomic intervals and testing those counts for significant differences between conditions.
This defines a set of putative DB regions for further examination.
DB analyses are statistically easier to perform than their conventional counterparts,
as the effect of genomic biases is largely mitigated when counts for different libraries are compared at the same genomic region.
DB regions may also be more relevant as the change in binding can be associated with the biological difference between conditions.

This book describes the use of the *[csaw](https://bioconductor.org/packages/3.15/csaw)* Bioconductor package to detect differential binding (DB) in ChIP-seq experiments with sliding windows [@lun2016csaw].
In these analyses, we detect and summarize DB regions between conditions in a *de novo* manner, i.e., without making any prior assumptions about the location or width of bound regions.
We demonstrate on data from a variety of real studies focusing on changes in transcription factor binding and histone mark enrichment. 
Our aim is to facilitate the practical implementation of window-based DB analyses by providing detailed code and expected output.
The code here can be adapted to any dataset with multiple experimental conditions and with multiple biological samples within one or more of the conditions;
it is similarly straightforward to accommodate batch effects, covariates and additional experimental factors.
Indeed, though the book focuses on ChIP-seq, the same software can be adapted to data from any sequencing technique where reads represent coverage of enriched genomic regions.

## How to read this book

The descriptions in this book explore the theoretical and practical motivations behind each step of a *[csaw](https://bioconductor.org/packages/3.15/csaw)* analysis.
While all users are welcome to read it from start to finish, new users may prefer to examine the case studies presented in the later sections [@lun2015from], 
which provides the important information in a more concise format.
Experienced users (or those looking for some nighttime reading!) are more likely to benefit from the in-depth discussions in this document.

All of the workflows described here start from sorted and indexed BAM files in the *[chipseqDBData](https://bioconductor.org/packages/3.15/chipseqDBData)* package.
For application to user-specified data, the raw read sequences have to be aligned to the appropriate reference genome beforehand.
Most aligners can be used for this purpose, but we have used *[Rsubread](https://bioconductor.org/packages/3.15/Rsubread)* [@liao2013] due to the convenience of its R interface.
It is also recommended to mark duplicate reads using tools like `Picard` prior to starting the workflow.

The statistical methods described here are based upon those in the *[edgeR](https://bioconductor.org/packages/3.15/edgeR)* package [@robinson2010]. 
Knowledge of *[edgeR](https://bioconductor.org/packages/3.15/edgeR)* is useful but not a prerequesite for reading this guide.

## How to get help

Most questions about *[csaw](https://bioconductor.org/packages/3.15/csaw)* should be answered by the documentation. 
Every function mentioned in this guide has its own help page. 
For example, a detailed description of the arguments and output of the `windowCounts()` function can be obtained by typing `?windowCounts` or `help(windowCounts)` at the R prompt. 
Further detail on the methods or the underlying theory can be found in the references at the bottom of each help page.

The authors of the package always appreciate receiving reports of bugs in the package functions or in the documentation. 
The same goes for well-considered suggestions for improvements. 
Other questions about how to use *[csaw](https://bioconductor.org/packages/3.15/csaw)* are best sent to the [Bioconductor support site](https://support.bioconductor.org).
Please send requests for general assistance and advice to the support site, rather than to the individual authors. 
Users posting to the support site for the first time may find it helpful to read the [posting guide](http://www.bioconductor.org/help/support/posting-guide).

## How to cite this book

Most users of *[csaw](https://bioconductor.org/packages/3.15/csaw)* should cite the following in any publications:

> A. T. Lun and G. K. Smyth. 
csaw: a Bioconductor package for differential binding analysis of ChIP-seq data using sliding windows. 
_Nucleic Acids Res._, 44(5):e45, Mar 2016

To cite the workflows specifically, we can use:

> A. T. L. Lun and G. K. Smyth. 
From reads to regions: a Bioconductor workflow to detect differential binding in ChIP-seq data. 
_F1000Research_, 4, 2015

For people interested in combined $p$-values, their use in DB analyses was proposed in:

> A. T. Lun and G. K. Smyth. 
De novo detection of differentially bound regions for ChIP-seq data using peaks and windows: controlling error rates correctly. 
_Nucleic Acids Res._, 42(11):e95, Jul 2014

The DB analyses shown here use methods from the *[edgeR](https://bioconductor.org/packages/3.15/edgeR)* package, which has its own citation recommendations.
See the appropriate section of the *[edgeR](https://bioconductor.org/packages/3.15/edgeR)* user's guide for more details.

## Quick start

A typical ChIP-seq analysis in *[csaw](https://bioconductor.org/packages/3.15/csaw)* would look something like that described below. 
This assumes that a vector of file paths to sorted and indexed BAM files is provided in \Robject{bam.files} and a design matrix in supplied in \Robject{design}.
The code is split across several steps:


```r
library(chipseqDBData)
tf.data <- NFYAData()
tf.data <- head(tf.data, -1) # skip the input.
bam.files <- tf.data$Path

cell.type <- sub("NF-YA ([^ ]+) .*", "\\1", tf.data$Description)
design <- model.matrix(~factor(cell.type))
colnames(design) <- c("intercept", "cell.type")
```

1. Loading in data from BAM files.

    
    ```r
    library(csaw)
    param <- readParam(minq=20)
    data <- windowCounts(bam.files, ext=110, width=10, param=param)
    ```

2. Filtering out uninteresting regions.

    
    ```r
    binned <- windowCounts(bam.files, bin=TRUE, width=10000, param=param)
    keep <- filterWindowsGlobal(data, binned)$filter > log2(5)
    data <- data[keep,]
    ```

3. Calculating normalization factors.

    
    ```r
    data <- normFactors(binned, se.out=data)
    ```

4. Identifying DB windows.

    
    ```r
    library(edgeR)
    y <- asDGEList(data)
    y <- estimateDisp(y, design)
    fit <- glmQLFit(y, design, robust=TRUE)
    results <- glmQLFTest(fit)
    ```

5. Correcting for multiple testing.

    
    ```r
    merged <- mergeResults(data, results$table, tol=1000L)
    ```

## Session information {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.2.1 (2022-06-23)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 20.04.4 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.15-bioc/R/lib/libRblas.so
LAPACK: /home/biocbuild/bbs-3.15-bioc/R/lib/libRlapack.so

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] edgeR_3.38.4                limma_3.52.2               
 [3] csaw_1.30.1                 SummarizedExperiment_1.26.1
 [5] Biobase_2.56.0              MatrixGenerics_1.8.1       
 [7] matrixStats_0.62.0          GenomicRanges_1.48.0       
 [9] GenomeInfoDb_1.32.3         IRanges_2.30.1             
[11] S4Vectors_0.34.0            BiocGenerics_0.42.0        
[13] chipseqDBData_1.12.0        BiocStyle_2.24.0           

loaded via a namespace (and not attached):
 [1] bitops_1.0-7                  bit64_4.0.5                  
 [3] filelock_1.0.2                httr_1.4.4                   
 [5] tools_4.2.1                   bslib_0.4.0                  
 [7] utf8_1.2.2                    R6_2.5.1                     
 [9] DBI_1.1.3                     tidyselect_1.1.2             
[11] bit_4.0.4                     curl_4.3.2                   
[13] compiler_4.2.1                rebook_1.6.0                 
[15] graph_1.74.0                  cli_3.3.0                    
[17] DelayedArray_0.22.0           bookdown_0.28                
[19] sass_0.4.2                    rappdirs_0.3.3               
[21] stringr_1.4.1                 digest_0.6.29                
[23] Rsamtools_2.12.0              rmarkdown_2.16               
[25] XVector_0.36.0                pkgconfig_2.0.3              
[27] htmltools_0.5.3               dbplyr_2.2.1                 
[29] fastmap_1.1.0                 rlang_1.0.4                  
[31] RSQLite_2.2.16                shiny_1.7.2                  
[33] jquerylib_0.1.4               generics_0.1.3               
[35] jsonlite_1.8.0                BiocParallel_1.30.3          
[37] dplyr_1.0.9                   RCurl_1.98-1.8               
[39] magrittr_2.0.3                GenomeInfoDbData_1.2.8       
[41] Matrix_1.4-1                  Rcpp_1.0.9                   
[43] fansi_1.0.3                   lifecycle_1.0.1              
[45] stringi_1.7.8                 yaml_2.3.5                   
[47] zlibbioc_1.42.0               BiocFileCache_2.4.0          
[49] AnnotationHub_3.4.0           grid_4.2.1                   
[51] blob_1.2.3                    parallel_4.2.1               
[53] promises_1.2.0.1              ExperimentHub_2.4.0          
[55] crayon_1.5.1                  lattice_0.20-45              
[57] dir.expiry_1.4.0              splines_4.2.1                
[59] Biostrings_2.64.1             KEGGREST_1.36.3              
[61] locfit_1.5-9.6                CodeDepends_0.6.5            
[63] metapod_1.4.0                 knitr_1.40                   
[65] pillar_1.8.1                  codetools_0.2-18             
[67] XML_3.99-0.10                 glue_1.6.2                   
[69] BiocVersion_3.15.2            evaluate_0.16                
[71] BiocManager_1.30.18           png_0.1-7                    
[73] vctrs_0.4.1                   httpuv_1.6.5                 
[75] purrr_0.3.4                   assertthat_0.2.1             
[77] cachem_1.0.6                  xfun_0.32                    
[79] mime_0.12                     xtable_1.8-4                 
[81] later_1.3.0                   tibble_3.1.8                 
[83] AnnotationDbi_1.58.0          memoise_2.0.1                
[85] statmod_1.4.37                ellipsis_0.3.2               
[87] interactiveDisplayBase_1.34.0
```
</div>

==> csawBook_1.6.1.tar.gz: csawBook/inst/doc/book/index.md <==
--- 
title: "The csaw Book"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
description: "ChIP-seq Analysis with Windows. But it works on Mac and Linux too!"
github-repo: LTLA/csawUsersGuide
---



---
date: "**Authors:** Aaron Lun [aut, cre]<br/>
  **Version:** 1.6.1<br/>
  **Modified:** 2023-03-24<br/>
  **Compiled:** 2023-03-31<br/>
  **Environment:** R version 4.2.3 (2023-03-15), Bioconductor 3.16<br/>
  **License:** GPL-3<br/>
  **Copyright:** Bioconductor, 2020<br/>
  **Source:** https://github.com/LTLA/csawUsersGuide"
url: "https://github.com/LTLA/csawUsersGuide"
---

# Welcome

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

Chromatin immunoprecipitation with sequencing (ChIP-seq) is a widely used technique for identifying the genomic binding sites of a target protein.
Conventional analyses of ChIP-seq data aim to detect absolute binding (i.e., the presence or absence of a binding site) based on peaks in the read coverage.
An alternative analysis strategy is to detect of changes in the binding profile between conditions [@rossinnes2012differential; @pal2013].
These differential binding (DB) analyses involve counting reads into genomic intervals and testing those counts for significant differences between conditions.
This defines a set of putative DB regions for further examination.
DB analyses are statistically easier to perform than their conventional counterparts,
as the effect of genomic biases is largely mitigated when counts for different libraries are compared at the same genomic region.
DB regions may also be more relevant as the change in binding can be associated with the biological difference between conditions.

This book describes the use of the *[csaw](https://bioconductor.org/packages/3.16/csaw)* Bioconductor package to detect differential binding (DB) in ChIP-seq experiments with sliding windows [@lun2016csaw].
In these analyses, we detect and summarize DB regions between conditions in a *de novo* manner, i.e., without making any prior assumptions about the location or width of bound regions.
We demonstrate on data from a variety of real studies focusing on changes in transcription factor binding and histone mark enrichment. 
Our aim is to facilitate the practical implementation of window-based DB analyses by providing detailed code and expected output.
The code here can be adapted to any dataset with multiple experimental conditions and with multiple biological samples within one or more of the conditions;
it is similarly straightforward to accommodate batch effects, covariates and additional experimental factors.
Indeed, though the book focuses on ChIP-seq, the same software can be adapted to data from any sequencing technique where reads represent coverage of enriched genomic regions.

## How to read this book

The descriptions in this book explore the theoretical and practical motivations behind each step of a *[csaw](https://bioconductor.org/packages/3.16/csaw)* analysis.
While all users are welcome to read it from start to finish, new users may prefer to examine the case studies presented in the later sections [@lun2015from], 
which provides the important information in a more concise format.
Experienced users (or those looking for some nighttime reading!) are more likely to benefit from the in-depth discussions in this document.

All of the workflows described here start from sorted and indexed BAM files in the *[chipseqDBData](https://bioconductor.org/packages/3.16/chipseqDBData)* package.
For application to user-specified data, the raw read sequences have to be aligned to the appropriate reference genome beforehand.
Most aligners can be used for this purpose, but we have used *[Rsubread](https://bioconductor.org/packages/3.16/Rsubread)* [@liao2013] due to the convenience of its R interface.
It is also recommended to mark duplicate reads using tools like `Picard` prior to starting the workflow.

The statistical methods described here are based upon those in the *[edgeR](https://bioconductor.org/packages/3.16/edgeR)* package [@robinson2010]. 
Knowledge of *[edgeR](https://bioconductor.org/packages/3.16/edgeR)* is useful but not a prerequesite for reading this guide.

## How to get help

Most questions about *[csaw](https://bioconductor.org/packages/3.16/csaw)* should be answered by the documentation. 
Every function mentioned in this guide has its own help page. 
For example, a detailed description of the arguments and output of the `windowCounts()` function can be obtained by typing `?windowCounts` or `help(windowCounts)` at the R prompt. 
Further detail on the methods or the underlying theory can be found in the references at the bottom of each help page.

The authors of the package always appreciate receiving reports of bugs in the package functions or in the documentation. 
The same goes for well-considered suggestions for improvements. 
Other questions about how to use *[csaw](https://bioconductor.org/packages/3.16/csaw)* are best sent to the [Bioconductor support site](https://support.bioconductor.org).
Please send requests for general assistance and advice to the support site, rather than to the individual authors. 
Users posting to the support site for the first time may find it helpful to read the [posting guide](http://www.bioconductor.org/help/support/posting-guide).

## How to cite this book

Most users of *[csaw](https://bioconductor.org/packages/3.16/csaw)* should cite the following in any publications:

> A. T. Lun and G. K. Smyth. 
csaw: a Bioconductor package for differential binding analysis of ChIP-seq data using sliding windows. 
_Nucleic Acids Res._, 44(5):e45, Mar 2016

To cite the workflows specifically, we can use:

> A. T. L. Lun and G. K. Smyth. 
From reads to regions: a Bioconductor workflow to detect differential binding in ChIP-seq data. 
_F1000Research_, 4, 2015

For people interested in combined $p$-values, their use in DB analyses was proposed in:

> A. T. Lun and G. K. Smyth. 
De novo detection of differentially bound regions for ChIP-seq data using peaks and windows: controlling error rates correctly. 
_Nucleic Acids Res._, 42(11):e95, Jul 2014

The DB analyses shown here use methods from the *[edgeR](https://bioconductor.org/packages/3.16/edgeR)* package, which has its own citation recommendations.
See the appropriate section of the *[edgeR](https://bioconductor.org/packages/3.16/edgeR)* user's guide for more details.

## Quick start

A typical ChIP-seq analysis in *[csaw](https://bioconductor.org/packages/3.16/csaw)* would look something like that described below. 
This assumes that a vector of file paths to sorted and indexed BAM files is provided in \Robject{bam.files} and a design matrix in supplied in \Robject{design}.
The code is split across several steps:


```r
library(chipseqDBData)
tf.data <- NFYAData()
tf.data <- head(tf.data, -1) # skip the input.
bam.files <- tf.data$Path

cell.type <- sub("NF-YA ([^ ]+) .*", "\\1", tf.data$Description)
design <- model.matrix(~factor(cell.type))
colnames(design) <- c("intercept", "cell.type")
```

1. Loading in data from BAM files.

    
    ```r
    library(csaw)
    param <- readParam(minq=20)
    data <- windowCounts(bam.files, ext=110, width=10, param=param)
    ```

2. Filtering out uninteresting regions.

    
    ```r
    binned <- windowCounts(bam.files, bin=TRUE, width=10000, param=param)
    keep <- filterWindowsGlobal(data, binned)$filter > log2(5)
    data <- data[keep,]
    ```

3. Calculating normalization factors.

    
    ```r
    data <- normFactors(binned, se.out=data)
    ```

4. Identifying DB windows.

    
    ```r
    library(edgeR)
    y <- asDGEList(data)
    y <- estimateDisp(y, design)
    fit <- glmQLFit(y, design, robust=TRUE)
    results <- glmQLFTest(fit)
    ```

5. Correcting for multiple testing.

    
    ```r
    merged <- mergeResults(data, results$table, tol=1000L)
    ```

## Session information {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.2.3 (2023-03-15)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 20.04.6 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.16-bioc/R/lib/libRblas.so
LAPACK: /home/biocbuild/bbs-3.16-bioc/R/lib/libRlapack.so

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] edgeR_3.40.2                limma_3.54.2               
 [3] csaw_1.32.0                 SummarizedExperiment_1.28.0
 [5] Biobase_2.58.0              MatrixGenerics_1.10.0      
 [7] matrixStats_0.63.0          GenomicRanges_1.50.2       
 [9] GenomeInfoDb_1.34.9         IRanges_2.32.0             
[11] S4Vectors_0.36.2            BiocGenerics_0.44.0        
[13] chipseqDBData_1.14.0        BiocStyle_2.26.0           

loaded via a namespace (and not attached):
 [1] bitops_1.0-7                  bit64_4.0.5                  
 [3] filelock_1.0.2                httr_1.4.5                   
 [5] tools_4.2.3                   bslib_0.4.2                  
 [7] utf8_1.2.3                    R6_2.5.1                     
 [9] DBI_1.1.3                     withr_2.5.0                  
[11] tidyselect_1.2.0              bit_4.0.5                    
[13] curl_5.0.0                    compiler_4.2.3               
[15] rebook_1.8.0                  graph_1.76.0                 
[17] cli_3.6.1                     DelayedArray_0.24.0          
[19] bookdown_0.33                 sass_0.4.5                   
[21] rappdirs_0.3.3                digest_0.6.31                
[23] Rsamtools_2.14.0              rmarkdown_2.21               
[25] XVector_0.38.0                pkgconfig_2.0.3              
[27] htmltools_0.5.5               dbplyr_2.3.2                 
[29] fastmap_1.1.1                 rlang_1.1.0                  
[31] RSQLite_2.3.0                 shiny_1.7.4                  
[33] jquerylib_0.1.4               generics_0.1.3               
[35] jsonlite_1.8.4                BiocParallel_1.32.6          
[37] dplyr_1.1.1                   RCurl_1.98-1.12              
[39] magrittr_2.0.3                GenomeInfoDbData_1.2.9       
[41] Matrix_1.5-3                  Rcpp_1.0.10                  
[43] fansi_1.0.4                   lifecycle_1.0.3              
[45] yaml_2.3.7                    zlibbioc_1.44.0              
[47] BiocFileCache_2.6.1           AnnotationHub_3.6.0          
[49] grid_4.2.3                    blob_1.2.4                   
[51] parallel_4.2.3                promises_1.2.0.1             
[53] ExperimentHub_2.6.0           crayon_1.5.2                 
[55] dir.expiry_1.6.0              lattice_0.20-45              
[57] splines_4.2.3                 Biostrings_2.66.0            
[59] KEGGREST_1.38.0               locfit_1.5-9.7               
[61] CodeDepends_0.6.5             metapod_1.6.0                
[63] knitr_1.42                    pillar_1.9.0                 
[65] codetools_0.2-19              XML_3.99-0.14                
[67] glue_1.6.2                    BiocVersion_3.16.0           
[69] evaluate_0.20                 BiocManager_1.30.20          
[71] png_0.1-8                     vctrs_0.6.1                  
[73] httpuv_1.6.9                  purrr_1.0.1                  
[75] cachem_1.0.7                  xfun_0.38                    
[77] mime_0.12                     xtable_1.8-4                 
[79] later_1.3.0                   tibble_3.2.1                 
[81] AnnotationDbi_1.60.2          memoise_2.0.1                
[83] statmod_1.5.0                 ellipsis_0.3.2               
[85] interactiveDisplayBase_1.36.0
```
</div>
